@@ -1,7 +1,7 @@
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-use crate::route::InjectiveRoute;
+use crate::{msg::OrderInfo, route::InjectiveRoute};
 use cosmwasm_std::{CustomQuery, Decimal256 as Decimal};
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
@@ -37,29 +37,25 @@ pub struct SubaccountDepositResponse {
 #[allow(non_snake_case)]
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct Position {
+    #[serde(default)]
     pub isLong: bool,
     pub quantity: Decimal,
     pub entry_price: Decimal,
+    #[serde(default)]
     pub margin: Decimal,
     pub cumulative_funding_entry: Decimal,
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct EffectivePosition {
+    #[serde(default)]
     pub is_long: bool,
     pub quantity: Decimal,
     pub entry_price: Decimal,
+    #[serde(default)]
     pub effective_margin: Decimal,
 }
 
-#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
-pub struct OrderInfo {
-    pub subaccount_id: String,
-    pub fee_recipient: String,
-    pub price: Decimal,
-    pub quantity: Decimal,
-}
-
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct DerivativeLimitOrder {
     pub order_info: OrderInfo,
@@ -70,6 +66,29 @@ pub struct DerivativeLimitOrder {
     pub order_hash: String,
 }
 
+impl DerivativeLimitOrder {
+    pub fn new(
+        margin: Decimal,
+        fillable: Decimal,
+        order_hash: String,
+        trigger_price: Option<Decimal>,
+        order_type: i32,
+        order_info: OrderInfo,
+    ) -> DerivativeLimitOrder {
+        DerivativeLimitOrder {
+            margin,
+            fillable,
+            order_hash,
+            trigger_price,
+            order_type,
+            order_info,
+        }
+    }
+    pub fn is_reduce_only(&self) -> bool {
+        self.margin.is_zero()
+    }
+}
+
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct DerivativePosition {
     pub subaccount_id: String,
@@ -115,23 +134,31 @@ pub struct DerivativeMarketResponse {
 /// Deposit is data format for the subaccount deposit
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct Deposit {
+    #[serde(default)]
     pub available_balance: Decimal,
+    #[serde(default)]
     pub total_balance: Decimal,
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct PerpetualMarketInfo {
     pub market_id: String,
+    #[serde(default)]
     pub hourly_funding_rate_cap: Decimal,
+    #[serde(default)]
     pub hourly_interest_rate: Decimal,
+    #[serde(default)]
     pub next_funding_timestamp: i64,
     pub funding_interval: i64,
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct PerpetualMarketFunding {
+    #[serde(default)]
     pub cumulative_funding: Decimal,
+    #[serde(default)]
     pub cumulative_price: Decimal,
+    #[serde(default)]
     pub last_timestamp: i64,
 }
 
@@ -159,7 +186,9 @@ pub struct DerivativeMarket {
     pub ticker: String,
     pub oracle_base: String,
     pub oracle_quote: String,
+    #[serde(default)]
     pub oracle_type: i32,
+    #[serde(default)]
     pub oracle_scale_factor: u32,
     pub quote_denom: String,
     pub market_id: String,
@@ -167,7 +196,9 @@ pub struct DerivativeMarket {
     pub maintenance_margin_ratio: Decimal,
     pub maker_fee_rate: Decimal,
     pub taker_fee_rate: Decimal,
+    #[serde(default)]
     pub isPerpetual: bool,
+    #[serde(default)]
     pub status: i32,
     pub min_price_tick_size: Decimal,
     pub min_quantity_tick_size: Decimal,
